{% extends base %}
{% load cms %}
{% block main_content %}
    <form action="{{ action_url }}" method="post">
        {% csrf_token %}

        {% if versions %}
            {% for v in versions %}
            <p class="checkbox">
                <input type="radio" name="version" id="version_{{ v.vid }}" value="{{ v.vid }}" />
                <label for="version_{{ v.vid }}">{{ v.status_line }}</label>
            </p>
            {% endfor %}

            <div class="button-group button-group--submit">
              <a class="button button--secondary" href="{{ done_url }} ">Cancel</a>
              <input class="button button--secondary" type="submit" name="delete" value="Delete" />
              <input class="button button--primary" type="submit" name="revert" value="Revert" />
            </div>
        {% else %}
            <p>There are no other versions of this item yet.</p>
        {% endif %}
    </form>
{% endblock %}
