{% extends base %}
{% load cms %}
{% block main_content %}
    <form action="{{ action_url }}" method="post">
        {% csrf_token %}

    {% if not protected %}
    <p>Please confirm that you want to delete the <strong class="object-name">{{ obj }}</strong></p>
    {% bundle_url bundle "main_list" as cancel_url %}
    <p class="submit-row">
        <a class="button" href="{{ cancel_url }} ">Cancel</a>
        <input class="big" type="submit" name='delete' value="Delete" />
    </p>
    {% else %}

    <p>Cannot delete '{{ obj }}' because the following objects depend on it.</p>

    {% for p in protected %}
    <p>{{ p }}</p>
    {% endfor %}
    {% endif %}
    </form>
{% endblock %}
