button,
.button {
	display: inline-block;
	cursor: pointer;
	min-width: $button-width;
	line-height: 40px;
	text-align: center;
	font-size: 14px;
	transition: background-color 200ms;

	.fa {
		margin-right: 4px;
	}

	&--primary {
		color: $white;
		background-color: #0084ff;
		padding: 0 15px;

		&.active,
		&:hover {
			color: $white;
			background-color: $blue-dark;
		}
	}

	&--secondary {
		color: $white;
		background-color: $gray;

		&.active,
		&:hover {
			color: $white;
			background-color: $gray-dark;
		}
	}

	&--tertiary {
		color: $white;
		background-color: $red-pom;

		&.active,
		&:hover {
			color: $white;
			background-color: $red-pom-dark;
		}
	}

	&--disabled {
		color: $white;
		cursor: default;
		background-color: $gray-light;

		&:hover {
			color: $white;
			background-color: $gray-light;
		}
	}

	&:focus {
		outline: none;
	}
}

.button-group {
	@include microfix;

	.button:not(:last-child) {
		margin-right: 10px;
	}

	.divider {
		float: left;

		&:not(:last-child) {
			@include divider($size: 38px, $space: 20px, $color: $gray);
		}
	}

	&--actions {
		padding-bottom: 20px;
		border-bottom: $gray-light 1px solid;
	}

	&--submit {
		padding-top: 40px;
		border-top: $gray-light 1px solid;
		margin-top: 50px;
		text-align: right;
	}
	.button_inner-container {
		position: relative;
		display: inline-block;
		.button__loading-overlay {
			position: absolute;
			top: 0;
			right: 10px;
			opacity: 0.8;
			z-index: 1;
			content: "";
			background: $gray-dark;
			height: 100%;
			width: 150px;
			display: none;
			&--active {
				display: flex;
			}
		}
	}
}

.lds-ring {
	display: inline-block;
	position: relative;
	width: 40px;
	height: 40px;
	margin: auto;
	div {
		box-sizing: border-box;
		display: block;
		position: absolute;
		width: 30px;
		height: 30px;
		margin: 5px;
		border: 5px solid #fff;
		border-radius: 50%;
		animation: lds-ring 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;
		border-color: #fff transparent transparent transparent;
		&:nth-child(1) {
			animation-delay: -0.45s;
		}
		&:nth-child(2) {
			animation-delay: -0.3s;
		}
		&:nth-child(3) {
			animation-delay: -0.15s;
		}
	}
}
@keyframes lds-ring {
	0% {
		transform: rotate(0deg);
	}
	100% {
		transform: rotate(360deg);
	}
}
