{% extends "cms/base_site.html" %}
{% load i18n %}
{% block userlinks %}{% trans 'Change password' %} / <a href="{% url 'admin:cms_logout' %}">{% trans 'Log out' %}</a>{% endblock %}

{% block title %}{% trans 'Password change successful' %}{% endblock %}

{% block content %}

<p style="text-align: center; margin-top:70px;">
	{% trans 'Your password has been changed successfully!' %}
	<br/>
	<a style="margin-top: 20px; display: block;" href="{% url 'admin:cms_index' %}">Homepage</a>
</p>

{% endblock %}
