.crop-list {
	&__name {
		display: block;
	}

	&__dimensions {
		color: #b8b8b8;
		font-size: 12px;
		display: block;
	}
}

.crop-info {
	strong {
		font-weight: 700;
	}
}

.color {
	&--red {
		color: $red-pom;
	}
	&--blue {
		color: $blue;
	}
}

.apply-crop {
	display: block;
	float: left;
	opacity: 1;
	max-height: none;
	overflow: visible;
	position: relative;
	&--hidden {
		overflow: hidden;
		opacity: 0;
		max-height: 0;
	}
	.check {
		position: absolute;
		left: 100%;
		height: 40px;
		width: 40px;
		opacity: 0;
		transition: 0.5s opacity ease;
	}
	&.clicked .check{
		opacity: 1;
	}
}

.preview-image {
	display: block;
	float: left;
	clear: left;
	margin-top: 20px;
}

.apply-crop--hidden ~ .preview-image {
	display: none;
}