# Generated by Django 2.2.16 on 2021-01-28 00:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pagebuilder', '0002_auto_20210125_1906'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='basecarouselmodule',
            name='display_arrow_at_end',
        ),
        migrations.RemoveField(
            model_name='basecarouselmodule',
            name='display_slide_indicator',
        ),
        migrations.RemoveField(
            model_name='basecarouselmodule',
            name='left_arrow_active',
        ),
        migrations.RemoveField(
            model_name='basecarouselmodule',
            name='loop_carousel',
        ),
        migrations.RemoveField(
            model_name='basecarouselmodule',
            name='right_arrow_active',
        ),
        migrations.RemoveField(
            model_name='basecarouselmodule',
            name='visible_image',
        ),
        migrations.RemoveField(
            model_name='basefaqmodule',
            name='answer_text_align',
        ),
        migrations.RemoveField(
            model_name='basefaqmodule',
            name='question_text_align',
        ),
        migrations.RemoveField(
            model_name='baseheadermodule',
            name='header_text_align',
        ),
        migrations.RemoveField(
            model_name='baseheadermodule',
            name='subheader_text_align',
        ),
        migrations.RemoveField(
            model_name='baseheromodule',
            name='button_align',
        ),
        migrations.RemoveField(
            model_name='baseheromodule',
            name='header_align',
        ),
        migrations.RemoveField(
            model_name='baseheromodule',
            name='subheader_text_align',
        ),
        migrations.RemoveField(
            model_name='basetwocolumnmodule',
            name='left_button_align',
        ),
        migrations.RemoveField(
            model_name='basetwocolumnmodule',
            name='left_description_align',
        ),
        migrations.RemoveField(
            model_name='basetwocolumnmodule',
            name='left_header_align',
        ),
        migrations.RemoveField(
            model_name='basetwocolumnmodule',
            name='right_button_align',
        ),
        migrations.RemoveField(
            model_name='basetwocolumnmodule',
            name='right_description_align',
        ),
        migrations.RemoveField(
            model_name='basetwocolumnmodule',
            name='right_header_align',
        ),
        migrations.AddField(
            model_name='basecarouselitem',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basecarouselitem',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basecarouselmodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basecarouselmodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basefaqitem',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basefaqitem',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basefaqmodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basefaqmodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basegalleryimage',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basegalleryimage',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseheadermodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseheadermodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseheromodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseheromodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseiconlistmodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseiconlistmodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseimagegallerymodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseimagegallerymodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baselocationitem',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baselocationitem',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baselocationmodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baselocationmodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basetwocolumnmodule',
            name='behavior',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basetwocolumnmodule',
            name='style',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
