# Generated by Django 2.2.16 on 2021-01-25 19:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pagebuilder', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='basecarouselitem',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basecarouselmodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basefaqitem',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basefaqmodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basegalleryimage',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseheadermodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseheromodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseiconlistmodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baseimagegallerymodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baselocationitem',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='baselocationmodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='basetwocolumnmodule',
            name='internal_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
