from .. import Provider as BaseProvider


# Ukrainian job names taken from
# https://uk.wikipedia.org/wiki/%D0%A1%D0%BF%D0%B8%D1%81%D0%BE%D0%BA_%D0%BF%D1%80%D0%BE%D1%84%D0%B5%D1%81%D1%96%D0%B9
# on 22th September 2014
class Provider(BaseProvider):
    jobs = [
        # А
        'Агроном', 'Адвокат', 'Актор', 'Акушер', 'Антрополог', 'Архітектор', 'Археолог', 'Астронавт', 'Астроном',
        'Астрофізик',
        # Б
        'Бібліограф', 'Біолог', 'Бізнесмен', 'Ботанік', 'Будник', 'Бухгалтер', 'Бібліотекар',
        # В
        'Ветеринар', 'Випробувач', 'Водій', 'Вчитель', 'Візажист',
        # Г
        'Географ', 'Геолог', 'Геофізик', 'Гицель', 'Гінеколог', 'Гірник', 'Гірничий інженер', 'Головний меркшейдер',
        'Графік', 'Громадський діяч',
        # Ґ
        'Ґрунтознавець',
        # Д
        'Державний службовець', 'Дерун', 'Детектив', 'Дизайнер', 'Дипломат', 'Диригент', 'Доцент', 'Драматург',
        'Ді-джей', 'Дантист',
        # Е
        'Економіст', 'Електрик', 'Електромонтер', 'Електромонтажник', 'Електрослюсар', 'Електротехнік', 'Епідеміолог',
        'Етнограф',
        # Є
        'Євнух', 'Єгер',
        # Ж
        'Журналіст', 'Живописець',
        # З
        'Золотар', 'Зоолог',
        # І
        'Інженер', 'Історик',
        # К
        'Каскадер', 'Кінорежисер', 'Клавішник', 'Клоун', 'Композитор', 'Конструктор', 'Краєзнавець', 'Кушнір',
        'Кіноактор', 'Кінокритик', 'Кінорежисер', 'Кур\'єр', 'Кухар', 'Кінолог', 'Круп\'є',
        # Л
        'Льотчик', 'Лікар', 'Літературознавець', 'Локсмайстер',
        # М
        'Математик', 'Машиніст', 'Медик', 'Менеджер', 'Мистецтвознавець', 'Мірошник', 'Мікробіолог', 'Мінералог',
        'Мовознавець', 'Модель', 'Модельєр', 'Музикант', 'Музикознавець', 'Музичний редактор', 'Маркетолог',
        'М\'ясник',
        # Н
        'Намотувальник', 'Науковець', 'Няня', 'Нотаріус',
        # П
        'Палеонтолог', 'Паралегал', 'Парфюмер', 'Патологоанатом', 'Педагог', 'Пекар', 'Перекладач', 'Петрограф',
        'Письменник', 'Піаніст', 'Підприємець', 'Пілот', 'Правник', 'Програміст', 'Провізор', 'Прокурор',
        'Промисловець', 'Професор', 'Психолог', 'Публіцист', 'Продюсер', 'Паблік рилейшнз',
        # Р
        'Режисер', 'Різноробочий', 'Реабілітолог', 'Редактор', 'Реставратор', 'Ріелтор',
        # С
        'Сантехнік', 'Складальник', 'Скульптор', 'Соціолог', 'Співак', 'Сценарист', 'Стропальник', 'Стоматолог',
        'Слідчий', 'Стиліст', 'Секретар',
        # Ф
        'Фармацевт', 'Фермер', 'Фізик', 'Філолог', 'Фольклорист', 'Фотограф', 'Фрілансер', 'Футболіст', 'Флорист',
        # Х
        'Хімік', 'Художник', 'Хореограф',
        # Ш
        'Шериф', 'Швачка', 'Штукатур',
        # Ю
        'Ювелір', 'Юрист',
    ]
