{% extends "cms/base_site.html" %}
{% load i18n %}

{% block content %}

<p>{% trans "Thanks for spending some quality time with the Web site today." %}</p>

<a class="button button--primary" href="{% url 'admin:cms_index' %}">{% trans 'Log in again' %}</a>

{% endblock %}
