@import '../vendor/ui-dialog';

.frame-wrapper {
  position: relative;
  padding-bottom: 52%;
  padding-top: 30px;
  height: 0;
  overflow: hidden;
  z-index: 10;

  iframe,
  object,
  embed {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
  }

  @media screen and (max-width: 700px) {
    position: relative;
    padding-bottom: 47%;
    padding-top: 30px;
    height: 0;
    overflow: hidden;
  }
}

.modal__frameWrap {
  height: 100%;
  width: 100%;
  position: absolute;
  top: 0;
  overflow: hidden;
}

body.modal__body {
  background: none;
  border: none;
  overflow: auto;

  #main {
    box-shadow: none;
    padding: 0;
    border-top: 0;

    &:before {
      display: none;
    }
  }

  #container {
    padding-bottom: 0;
  }
}



