# Generated by Django 2.2.11 on 2021-02-24 00:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pagebuilder', '0003_auto_20210128_0004'),
    ]

    operations = [
        migrations.RenameField(
            model_name='page_version',
            old_name='description',
            new_name='seo_description',
        ),
    ]
